==> svalbard-json-1.0.0-sources.jar: org/n52/svalbard/encode/json/NillableJSONEncoder.java <==
/*
 * Copyright 2016-2017 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.n52.svalbard.encode.json;

import org.n52.shetland.w3c.Nillable;
import org.n52.svalbard.coding.json.AQDJSONConstants;
import org.n52.svalbard.encode.exception.EncodingException;

import com.fasterxml.jackson.databind.JsonNode;

/**
 * TODO JavaDoc
 *
 * @author Christian Autermann
 */
public class NillableJSONEncoder extends JSONEncoder<Nillable<?>> {

    public NillableJSONEncoder() {
        super(Nillable.class);
    }

    @Override
    public JsonNode encodeJSON(Nillable<?> t)
            throws EncodingException {
        if (t.isAbsent()) {
            return nodeFactory().nullNode();
        } else if (t.isNil()) {
            return nodeFactory().objectNode()
                    .put(AQDJSONConstants.NIL, true)
                    .put(AQDJSONConstants.REASON, t.getNilReason().orNull());
        } else {
            return encodeObjectToJson(t.get());
        }
    }

}

==> svalbard-json-8.0.2-sources.jar: org/n52/svalbard/encode/json/NillableJSONEncoder.java <==
/*
 * Copyright 2015-2020 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.n52.svalbard.encode.json;

import org.n52.shetland.w3c.Nillable;
import org.n52.svalbard.coding.json.AQDJSONConstants;
import org.n52.svalbard.encode.exception.EncodingException;

import com.fasterxml.jackson.databind.JsonNode;

/**
 * TODO JavaDoc
 *
 * @author Christian Autermann
 */
public class NillableJSONEncoder extends JSONEncoder<Nillable<?>> {

    public NillableJSONEncoder() {
        super(Nillable.class);
    }

    @Override
    public JsonNode encodeJSON(Nillable<?> t)
            throws EncodingException {
        if (t.isAbsent()) {
            return nodeFactory().nullNode();
        } else if (t.isNil()) {
            return nodeFactory().objectNode()
                    .put(AQDJSONConstants.NIL, true)
                    .put(AQDJSONConstants.REASON, t.getNilReason().orElse(null));
        } else {
            return encodeObjectToJson(t.get());
        }
    }

}
